[![Build Status](https://ci.appveyor.com/api/projects/status/h4m43pwga7pjoftl/branch/master?svg=true)](https://ci.appveyor.com/project/bcdev/xcube)
[![codecov](https://codecov.io/gh/dcs4cop/xcube/branch/master/graph/badge.svg)](https://codecov.io/gh/dcs4cop/xcube)
[![Documentation Status](https://readthedocs.org/projects/xcube/badge/?version=latest)](https://xcube.readthedocs.io/en/latest/?badge=latest)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/xcube/badges/version.svg)](https://anaconda.org/conda-forge/xcube)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/xcube/badges/license.svg)](https://anaconda.org/conda-forge/xcube)

xcube is a Python toolkit for managing geospatial data cubes. 

It is based on popular data science packages such as 
[xarray](http://xarray.pydata.org/), [Zarr](https://zarr.readthedocs.io/), and [Dask](https://dask.org/).

Find out more in the [xcube Documentation](https://xcube.readthedocs.io).
